@@ -15,6 +15,7 @@ var GdeployUtil = {
     getDefaultGedeployModel() {
         return {
             hosts: ['', '', ''],
+            fqdns: ['', ''],
             subscription: {
                 username: "", password: "", poolId: "", yumUpdate: false,
                 rpms: "",
@@ -91,7 +92,12 @@ var GdeployUtil = {
         this.handleDirAndFileCreation(filePath, configString, function(result){
           callback(true)
         })
-        this.saveGdeployInventory(glusterModel)
+        const that = this
+        this.findGdeployVersion(function(isSupported) {
+          if(isSupported) {
+            that.saveGdeployInventory(glusterModel)
+          }
+        })
     },
     createPreFlightCheck(hosts, pvConfig) {
         let preFlightCheck = []
@@ -437,8 +443,8 @@ var GdeployUtil = {
               blockmapcachesize: "128M",
               readcache: "enabled",
               readcachesize: "20M",
-              emulate512: "enabled",
-              writepolicy: "sync",
+              emulate512: "on",
+              writepolicy: "auto",
               ignore_vdo_errors: "no"
             }
           }
@@ -463,6 +469,8 @@ var GdeployUtil = {
           logicalSizes.forEach(function(logicalSize, index) {
               if (parseInt(logicalSize) >= 1000) {
                   slabsizes.push("32G")
+              } else {
+                slabsizes.push("2G")
               }
           })
           hostVdoConfigs.vdoConfig.devices = devices.join()
@@ -668,16 +676,12 @@ var GdeployUtil = {
       cockpit.spawn(
         [ "vdo", "list" ], { "superuser":"require" }
       ).done(function(res){
-        cockpit.spawn(
-          [ "rpm", "-qa", "gdeploy" ], { "superuser":"require" }
-        ).done(function(gVersion){
-          if(that.isGdeploySupportVdo(gVersion)) {
+        that.findGdeployVersion(function(isSupported) {
+          if(isSupported) {
             callback(true)
           } else {
             callback(false)
           }
-        }).fail(function(code){
-          callback(false)
         })
       }).fail(function(code){
         callback(false)
@@ -686,42 +690,58 @@ var GdeployUtil = {
     // Creates file required to add the 2nd and 3rd hosts and storage domain
     // to the engine after successful HE deployment
     saveGdeployInventory(glusterModel) {
-      let inventoryModel = {
-        "gluster": {}
-      }
-      let sdModelList = []
-      let hostList = [glusterModel.hosts[1], glusterModel.hosts[2]]
-      let firstHostFqdn = glusterModel.hosts[0]
-      inventoryModel.gluster.hosts = hostList
-      let mntOptions = "backup-volfile-servers=" + hostList.join(":")
-      glusterModel.volumes.forEach(function(volume, index) {
-        if(index !== 0) {
-          let sdModel = {}
-          sdModel.name = volume.name
-          sdModel.host = firstHostFqdn
-          sdModel.address = firstHostFqdn
-          sdModel.path = volume.name
-          sdModel.mount_options = mntOptions
-          sdModelList.push(sdModel)
+      if(glusterModel.fqdns[0].length > 0 && glusterModel.fqdns[1].length > 0) {
+        let inventoryModel = {
+          "gluster": {}
         }
-      })
-      let gdeployInventory = "gluster:\n hosts:\n  " + glusterModel.hosts[1] + ":\n  " + glusterModel.hosts[2]
-                            + ":\n vars:\n  storage_domains: " + JSON.stringify(sdModelList)
-      let filePath = constants.gdeployInventoryFile
+        let sdModelList = []
+        let hostList = [glusterModel.hosts[1], glusterModel.hosts[2]]
+        let firstHostFqdn = glusterModel.hosts[0]
+        inventoryModel.gluster.hosts = hostList
+        let mntOptions = "backup-volfile-servers=" + hostList.join(":")
+        glusterModel.volumes.forEach(function(volume, index) {
+          if(index !== 0) {
+            let sdModel = {}
+            sdModel.name = volume.name
+            sdModel.host = firstHostFqdn
+            sdModel.address = firstHostFqdn
+            sdModel.path = volume.name
+            sdModel.mount_options = mntOptions
+            sdModelList.push(sdModel)
+          }
+        })
+        let gdeployInventory = "gluster:\n hosts:\n  " + glusterModel.fqdns[0] + ":\n  " + glusterModel.fqdns[1]
+                              + ":\n vars:\n  storage_domains: " + JSON.stringify(sdModelList)
+        let filePath = constants.gdeployInventoryFile
+        const that = this
+        const dirPath = filePath.substring(0, filePath.lastIndexOf("/"))
+        cockpit.script("if [ ! -d " + dirPath + " ]; then mkdir " + dirPath + "; fi", { "superuser": "require" })
+          .done(function(exitCode) {
+            const file = cockpit.file(filePath, {"superuser": "require" })
+            file.replace(gdeployInventory)
+                .always(function(tag) {
+                  console.log("tag: ", tag);
+                    file.close()
+                })
+          })
+          .fail(function(error) {
+            console.log("Failed to create " + dirPath + "directory: ", error);
+          })
+        }
+    },
+    findGdeployVersion(callback) {
       const that = this
-      const dirPath = filePath.substring(0, filePath.lastIndexOf("/"))
-      cockpit.script("if [ ! -d " + dirPath + " ]; then mkdir " + dirPath + "; fi", { "superuser": "require" })
-        .done(function(exitCode) {
-          const file = cockpit.file(filePath, {"superuser": "require" })
-          file.replace(gdeployInventory)
-              .always(function(tag) {
-                console.log("tag: ", tag);
-                  file.close()
-              })
-        })
-        .fail(function(error) {
-          console.log("Failed to create " + dirPath + "directory: ", error);
-        })
+      cockpit.spawn(
+        [ "rpm", "-qa", "gdeploy" ], { "superuser":"require" }
+      ).done(function(gVersion){
+        if(that.isGdeploySupportVdo(gVersion)) {
+          callback(true)
+        } else {
+          callback(false)
+        }
+      }).fail(function(code){
+        callback(false)
+      })
     },
     isGdeploySupportVdo(gVersion) {
       let gVersions = gVersion.split("-")
@@ -736,6 +756,19 @@ var GdeployUtil = {
       } else {
         return false
       }
+    },
+    isPingable(address, callBack) {
+      let proc = cockpit.spawn(
+          ["ping", "-w", "1",
+            address
+          ]
+      )
+      .done(function(code) {
+          callBack(true)
+      })
+      .fail(function(code) {
+          callBack(false)
+      })
     }
 }
 
